This function first look for all the R scripts under a
directory (using the pattern "\\.[RrSsQq]$"),
then uses tidy.source to tidy these
scripts. The original scripts will be overwritten with
formatted code. You may need to back up the original
directory first if you do not fully understand the tricks
tidy.source is using.
Usage
tidy.dir(path = ".", recursive = FALSE, ...)
Arguments
path
the directory
recursive
whether to recursively look for R
scripts under path