Learn R Programming

formatR (version 0.2-4)

usage: Show the usage of a function

Description

Print the usage of a function in a formatted way.

Usage

usage(FUN, class = NULL, w = 0.77)

Arguments

FUN
the function
class
provide the class to which the function is applied if FUN is a S3 generic function
w
the width of output

Value

  • NULL

See Also

tidy.source

Examples

Run this code
usage(var)

usage(plot)
## default method
usage(plot, "default")
## on the 'lm' class
usage(plot, "lm")

usage(usage)

# narrower output
usage(barplot, "default", 0.75)

Run the code above in your browser using DataLab